@@ -1,3 +1,9 @@
+/*
+ * Blue Engine copyright 2021 © Elham Aryanpur
+ *
+ * The license is same as the one on the root.
+*/
+
 /// Will contain all details about a vertex and will be sent to GPU
 // Will be turned to C code and sent to GPU
 #[repr(C)]
@@ -69,6 +75,26 @@ pub mod uniform_type {
     }
 }
 
+pub struct Object {
+    pub name: Option<&'static str>,
+    pub verticies: Vec<Vertex>,
+    pub indicies: Vec<u16>,
+    pub pipeline: Pipeline,
+    pub pipeline_id: Option<usize>,
+    pub window_size: winit::dpi::PhysicalSize<u32>,
+    pub width: f32,
+    pub height: f32,
+    pub depth: f32,
+    pub changed: bool
+}
+
+pub struct Engine {
+    pub renderer: Renderer,
+    pub event_loop: winit::event_loop::EventLoop<()>,
+    pub window: winit::window::Window,
+    pub objects: Vec<Object>,
+}
+
 // Container for pipeline values. Each pipeline takes only 1 vertex shader, 1 fragment shader, 1 texture data, and optionally a vector of uniform data.
 #[derive(Debug, Clone, Copy)]
 pub struct Pipeline {
@@ -106,13 +132,6 @@ pub struct Renderer {
     pub(crate) render_pipelines: Vec<Pipeline>,
 }
 
-// Callbacks for renderloop
-pub enum WindowCallbackEvents<'a> {
-    Before,                                           // This will run before the loop
-    During(&'a winit_input_helper::WinitInputHelper), // will be called during the loop
-    After, // will be called after the loop ended. Maybe for cleanup?
-}
-
 /// Descriptor and settings for a window.
 pub struct WindowDescriptor {
     /// The width of the window
